#
# spec file for package python-xxhash
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-xxhash
Version:        3.5.0
Release:        1.3
Summary:        Python binding for xxHash
License:        BSD-2-Clause
URL:            https://github.com/ifduyue/python-xxhash
Source:         https://files.pythonhosted.org/packages/source/x/xxhash/xxhash-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  xxhash-devel
%python_subpackages

%description
xxhash is a Python binding for the xxHash library.

%prep
%setup -q -n xxhash-%{version}

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export LANG=en_US.UTF-8
export XXHASH_LINK_SO=1
%python_build

%install
export LANG=en_US.UTF-8
export XXHASH_LINK_SO=1
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
export LANG=en_US.UTF-8
export XXHASH_LINK_SO=1
mv xxhash{,.hide}
%pyunittest_arch discover -v
mv xxhash{.hide,}

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/xxhash
%{python_sitearch}/xxhash-%{version}*-info

%changelog
* Thu Oct 10 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 3.5.0
  * Build wheels for Python 3.13
* Fri Nov 17 2023 ecsos <ecsos@opensuse.org>
- Update to 3.4.1
  - Build wheels for Python 3.12
  - Remove setuptools_scm
- Changes from 3.3.0
  - Upgrade xxHash to v0.8.2
  - Drop support for Python 3.6
- Changes from 3.2.0
  - Build Python 3.11 wheels.
  - Remove setup.py test_suites, call unittest directly
* Tue Oct 24 2023 Dirk Müller <dmueller@suse.com>
- use setuptools_scm to handle version in metadata properly
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.1.0
  * Type annotations.
  * Enabled muslinux wheels building.
* Fri Sep 16 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- update to 3.0.0
  * New set algorithms_available lists all implemented algorithms in xxhash package.
  * Upgrade xxHash to v0.8.1.
  * Drop support for EOL Python versions, require python >= 3.6 from now on.
  * Migrate to github actions and build arm64 wheels for macOS.
  * Always release GIL.
* Fri Aug 27 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Thu Aug 26 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.0.2
  * Fix Travis CI OSX dpl python2.7 get-pip.py error
- from version 2.0.1
  * Only to trigger Python 3.9 wheels building
* Mon Aug 24 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.0.0:
  * Require xxHash version >= v0.8.0
  * Upgrade xxHash to v0.8.0
  * XXH3 hashes: `xxh3_64`, `xxh3_128`, and their oneshot functions
* Tue Jul 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.4.4
  * Upgrade xxHash to v0.7.3
  * Stop using PEP393 deprecated APIs
  * Use XXH(32|64)_canonicalFromHash to replace u2bytes and ull2bytes
* Tue Feb  4 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.4.3
  * Upgrade xxHash to v0.7.2
  * Python 3.8 wheels
* Wed Oct 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4.2:
  * Fixed: setup.py fails when reading README.rst and the default encoding is not UTF-8
* Sat Sep  7 2019 John Vandenberg <jayvdb@gmail.com>
- Link against system libxxhash
- Fix Leap 15 build errors
* Thu Aug 29 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.4.1
  * Upgrade xxHash to v0.7.1
  * Fixed: xxh3.h in missing from source tarball
* Tue Mar 26 2019 pgajdos@suse.com
- version update to 1.3.0
  * Wheels are now built automatically
  * Split CFFI variant into a separate package
  * Add oneshot functions xxh{32,64}_{,int,hex}digest
  * Allow input larger than 2GB
  * Release the GIL on sufficiently large input
  * Drop support for Python 3.2
* Fri Nov 10 2017 alarrosa@suse.com
- Initial release of xxhash 1.0.1
